<?php

namespace EventPortal\Domain\Component\Column;

use Illuminate\Support\Str;

abstract class Column
{
    /** @var string */
    public $label;

    /** @var string */
    public $name;

    /** @var null|string|array[string] */
    public $value;

    /** @var bool */
    private $isDefault = false;

    /** @var bool */
    private $isSearchable = false;

    /** @var bool */
    private $isCalculated = false;

    public function __construct(string $label)
    {
        $this->label = $label;
        $this->name = Str::slug($label, '_');
    }

    public static function make(string $label): self
    {
        return new static($label);
    }

    public function name(string $name): self
    {
        $this->name = Str::slug($name, '_');

        return $this;
    }

    /**
     * @param string|array|callable $value
     */
    public function value($value): self
    {
        $this->value = $value ?: '';

        return $this;
    }

    public function default(): self
    {
        $this->isDefault = true;

        return $this;
    }

    public function searchable(): self
    {
        $this->isSearchable = true;

        return $this;
    }

    public function isDefault(): bool
    {
        return $this->isDefault;
    }

    public function isSearchable(): bool
    {
        return $this->isSearchable;
    }

    public function calculated(): self
    {
        $this->isCalculated = true;

        return $this;
    }

    public function isCalculated(): bool
    {
        return $this->isCalculated;
    }
}
