<?php

namespace EventPortal\Domain\Event\Form\Actions;

use EventPortal\Domain\Event\Form\Models\Question;
use EventPortal\Domain\Event\Form\Models\QuestionOption;
use EventPortal\Domain\Event\Form\ValueObjects\OptionData;
use Illuminate\Support\Arr;
use Illuminate\Support\Collection;

class UpdateOptions
{
    public function execute(Collection $options, Question $dbQuestion): void
    {
        self::deleteUnusedOptions($options, $dbQuestion);
        $options->each(static function (OptionData $option) use ($dbQuestion): void {
            QuestionOption::updateOrCreate(
                ['id' => $option->id],
                Arr::add($option->toArray(), 'question_id', $dbQuestion->id)
            );
        });
    }

    private static function deleteUnusedOptions(Collection $options, Question $question): void
    {
        QuestionOption::query()
            ->whereNotIn('id', $options->pluck('id'))
            ->forQuestion($question)
            ->delete();
    }
}
