<?php

namespace EventPortal\Domain\Event\Form\ValueObjects;

use Illuminate\Contracts\Support\Arrayable;
use Illuminate\Support\Arr;

class QuestionData implements Arrayable
{
    /** @var int */
    public $id;

    /** @var string */
    public $question;

    /** @var string */
    public $helpText;

    /** @var string */
    public $helpPosition;

    /** @var bool */
    public $required;

    /** @var int */
    public $order;

    /** @var string */
    public $uuid;

    /** @var string */
    public $type;

    /** @var string */
    public $gdprType;

    /** @var \Illuminate\Support\Collection */
    public $options;

    /** @var \Illuminate\Support\Collection */
    public $validations;

    public function __construct(array $question)
    {
        $this->id = (int) Arr::get($question, 'id');
        $this->question = Arr::get($question, 'question');
        $this->helpText = Arr::get($question, 'helpText');
        $this->helpPosition = Arr::get($question, 'helpPosition');
        $this->gdprType = Arr::get($question, 'gdprType');
        $this->required = (bool) Arr::get($question, 'required');
        $this->type = Arr::get($question, 'component.name.value');
        $this->order = (int) Arr::get($question, 'order');
        $this->uuid = Arr::get($question, 'uuid');
        $this->options = collect(Arr::get($question, 'component.options'))
            ->mapInto(OptionData::class)
            ->reject(static function ($option): bool {
                return $option->name === null;
            })
            ->filter();
        $this->validations = collect(Arr::get($question, 'validations'))
            ->mapInto(ValidationData::class)
            ->filter();
    }

    public function toArray(): array
    {
        return [
            'id' => $this->id,
            'question' => $this->question,
            'help_text' => $this->helpText,
            'help_position' => $this->helpPosition,
            'gdpr_type' => $this->gdprType,
            'required' => $this->required,
            'type' => $this->type,
            'order' => $this->order,
            'uuid' => $this->uuid,
        ];
    }
}
